"use strict";

var _Object$defineProperty = require("@babel/runtime-corejs3/core-js/object/define-property");
var _interopRequireDefault = require("@babel/runtime-corejs3/helpers/interopRequireDefault").default;
_Object$defineProperty(exports, "__esModule", {
  value: true
});
exports.MetaTags = void 0;
var _isArray = _interopRequireDefault(require("@babel/runtime-corejs3/core-js/array/is-array"));
var _index = require("../index");
var _jsxRuntime = require("react/jsx-runtime");
/**
 * Add commonly used <meta> tags for unfurling/seo purposes
 * using the open graph protocol https://ogp.me/
 * @example
 * <MetaTags title="About Page" ogContentUrl="/static/about-og.png"/>
 * @deprecated Please use <Metadata> instead
 */
const MetaTags = props => {
  const {
    tag = 'og:image',
    ogType = 'website',
    ogContentUrl,
    robots,
    contentType,
    ogWidth,
    ogHeight,
    ogUrl,
    title,
    locale,
    description,
    author,
    children
  } = props;
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_jsxRuntime.Fragment, {
    children: [title && /*#__PURE__*/(0, _jsxRuntime.jsxs)(_index.Head, {
      children: [/*#__PURE__*/(0, _jsxRuntime.jsx)("title", {
        children: title
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)("meta", {
        property: "og:title",
        content: title
      }, "title"), /*#__PURE__*/(0, _jsxRuntime.jsx)("meta", {
        property: "twitter:title",
        content: title
      })]
    }), description && /*#__PURE__*/(0, _jsxRuntime.jsxs)(_index.Head, {
      children: [/*#__PURE__*/(0, _jsxRuntime.jsx)("meta", {
        name: "description",
        content: description
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)("meta", {
        name: "twitter:description",
        content: description
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)("meta", {
        property: "og:description",
        content: description
      })]
    }), author && /*#__PURE__*/(0, _jsxRuntime.jsxs)(_index.Head, {
      children: [/*#__PURE__*/(0, _jsxRuntime.jsx)("meta", {
        name: "author",
        content: author
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)("meta", {
        name: "twitter:site",
        content: author
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)("meta", {
        name: "twitter:creator",
        content: author
      })]
    }), ogUrl && /*#__PURE__*/(0, _jsxRuntime.jsx)(_index.Head, {
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)("meta", {
        property: "og:url",
        content: ogUrl
      })
    }), locale && /*#__PURE__*/(0, _jsxRuntime.jsxs)(_index.Head, {
      children: [/*#__PURE__*/(0, _jsxRuntime.jsx)("html", {
        lang: locale
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)("meta", {
        property: "og:locale",
        content: locale
      })]
    }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index.Head, {
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)("meta", {
        property: "og:type",
        content: ogType
      })
    }), ogContentUrl && /*#__PURE__*/(0, _jsxRuntime.jsx)(_index.Head, {
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)("meta", {
        property: tag,
        content: ogContentUrl
      })
    }), contentType && /*#__PURE__*/(0, _jsxRuntime.jsx)(_index.Head, {
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)("meta", {
        property: `${tag}:type`,
        content: contentType
      })
    }), tag === 'og:image' && /*#__PURE__*/(0, _jsxRuntime.jsxs)(_index.Head, {
      children: [ogWidth && /*#__PURE__*/(0, _jsxRuntime.jsx)("meta", {
        property: "image:width",
        content: ogWidth
      }), ogHeight && /*#__PURE__*/(0, _jsxRuntime.jsx)("meta", {
        property: "image:height",
        content: ogHeight
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)("meta", {
        property: "twitter:card",
        content: "summary_large_image"
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)("meta", {
        property: "twitter:image",
        content: ogContentUrl
      })]
    }), robots && /*#__PURE__*/(0, _jsxRuntime.jsx)(_index.Head, {
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)("meta", {
        name: "robots",
        content: (0, _isArray.default)(robots) ? robots.join(', ') : robots
      })
    }), children]
  });
};
exports.MetaTags = MetaTags;