"use strict";

var _Object$defineProperty = require("@babel/runtime-corejs3/core-js/object/define-property");
_Object$defineProperty(exports, "__esModule", {
  value: true
});
exports.getOperationName = getOperationName;
/**
 * Given a query like the one below this function will return
 * `FindBlogPostQuery`
 *
 * ```
 *   export const QUERY = gql`
 *     query FindBlogPostQuery($id: Int!) {
 *       blogPost: post(id: $id) {
 *         id
 *         title
 *         body
 *         createdAt
 *       }
 *     }
 *   `
 * ```
 *
 * @param {DocumentNode} document
 *   graphql query or mutation to get the operation name for
 * @returns {string} empty string if no operation name could be found
 */
function getOperationName(document) {
  for (const definition of document.definitions) {
    if (definition.kind === 'OperationDefinition' && definition.name?.value) {
      return definition.name.value;
    }
  }
  return '';
}